@@ -6,9 +6,18 @@ from holour.msg import Vector3, Pose, Poses
 
 class Test(TestCase):
 
+    def setUp(self) -> None:
+        self.vector3 = Vector3(1, 2, 3)
+
+        self.name = "waypoint_1"
+        self.position = Vector3(1, 2, 3)
+        self.orientation = Vector3(-1.1, -1.2, 1.3)
+        self.pose = Pose(self.position, self.orientation, self.name)
+
+        self.poses = Poses([])
+
     def test_vector3(self):
-        vector3 = Vector3(1, 2, 3)
-        vector3_string = json_encode(vector3)
+        vector3_string = json_encode(self.vector3)
 
         assert type(vector3_string) == str
         assert vector3_string == '{"_type": "vector3", "x": 1, "y": 2, "z": 3}', f"Got: {vector3_string}"
@@ -16,23 +25,22 @@ class Test(TestCase):
         vector3_decoded = json_decode(vector3_string)
         assert type(vector3_decoded) == Vector3
         assert vector3_decoded.x == 1
-        assert vector3_decoded == vector3
+        assert vector3_decoded == self.vector3
 
     def test_vector3_equals(self):
-        v1 = Vector3(1, 2, 3)
         v2 = Vector3(1, 2, 3)
         v3 = Vector3(3000, 2, 3)
 
-        assert v1 == v2
-        assert v1 != v3
-        assert v1 != "hej"
+        assert self.vector3 == v2
+        assert self.vector3 != v3
+        assert self.vector3 != "hej"
+
+    def test_vector3_repr(self):
+        expected, got = 'x=1', f'{self.vector3}'
+        assert expected in got, f"Expected {expected} in got: {got}"
 
     def test_pose(self):
-        name = "waypoint_1"
-        position = Vector3(1, 2, 3)
-        orientation = Vector3(-1.1, -1.2, 1.3)
-        pose = Pose(position, orientation, name)
-        pose_string = json_encode(pose)
+        pose_string = json_encode(self.pose)
 
         assert type(pose_string) == str
         assert pose_string == '{"_type": "pose", "name": "waypoint_1", ' \
@@ -41,19 +49,22 @@ class Test(TestCase):
 
         pose_decoded: Pose = json_decode(pose_string)
         assert type(pose_decoded) == Pose, f"Expected object of type {Pose}"
-        assert pose_decoded.name == name
-        assert pose_decoded.position == position
-        assert pose_decoded.orientation == orientation
-        assert pose_decoded == pose
+        assert pose_decoded.name == self.name
+        assert pose_decoded.position == self.position
+        assert pose_decoded.orientation == self.orientation
+        assert pose_decoded == self.pose
 
     def test_pose_equals(self):
-        pose1 = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3))
-        pose2 = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3))
+        pose2 = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3), "waypoint_1")
         pose3 = Pose(Vector3(1, 2, 3), Vector3(-1.1, -1.2, 1.3), "some name")
 
-        assert pose1 == pose2
-        assert pose1 != pose3
-        assert pose1 != "hej"
+        assert self.pose == pose2
+        assert self.pose != pose3
+        assert self.pose != "hej"
+
+    def test_pose_repr(self):
+        expected, got = f'name={self.name}', f'{self.pose}'
+        assert expected in got, f"Expected {expected} in got: {got}"
 
     def test_poses(self):
         list_of_poses = [
@@ -89,9 +100,12 @@ class Test(TestCase):
         assert poses1 != list_of_poses
 
     def test_poses_add(self):
-        pose = Pose(Vector3(1, 1, 1), Vector3(-1.1, -1.2, 1.3), "waypoint_1")
-        poses = Poses([])
-        poses.add(pose)
+        assert len(self.poses.poses) == 0
 
-        assert len(poses.poses) == 1
-        assert pose in poses.poses
+        self.poses.add(self.pose)
+        assert len(self.poses.poses) == 1
+        assert self.pose in self.poses.poses
+
+    def test_poses_repr(self):
+        expected, got = f'connected=False', f'{self.poses}'
+        assert expected in got, f"Expected {expected} in got: {got}"
